==> eam-wshub-proxyclient-11.4-6-sources.jar: net/datastream/schemas/mp_results/mp0115_001/MP0115_DeleteDocumentAssociation_001_Result.java <==

package net.datastream.schemas.mp_results.mp0115_001;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;
import net.datastream.schemas.mp_fields.DOCUMENTENTITYID_Type;


/**
 * <p>Classe Java pour anonymous complex type.
 * 
 * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
 * 
 * <pre>
 * &lt;complexType>
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}DOCUMENTENTITYID"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "documententityid"
})
@XmlRootElement(name = "MP0115_DeleteDocumentAssociation_001_Result")
public class MP0115_DeleteDocumentAssociation_001_Result {

    @XmlElement(name = "DOCUMENTENTITYID", namespace = "http://schemas.datastream.net/MP_fields", required = true)
    protected DOCUMENTENTITYID_Type documententityid;

    /**
     * Obtient la valeur de la propriété documententityid.
     * 
     * @return
     *     possible object is
     *     {@link DOCUMENTENTITYID_Type }
     *     
     */
    public DOCUMENTENTITYID_Type getDOCUMENTENTITYID() {
        return documententityid;
    }

    /**
     * Définit la valeur de la propriété documententityid.
     * 
     * @param value
     *     allowed object is
     *     {@link DOCUMENTENTITYID_Type }
     *     
     */
    public void setDOCUMENTENTITYID(DOCUMENTENTITYID_Type value) {
        this.documententityid = value;
    }

}

==> eam-wshub-proxyclient-12.0-sources.jar: net/datastream/schemas/mp_results/mp0115_001/MP0115_DeleteDocumentAssociation_001_Result.java <==

package net.datastream.schemas.mp_results.mp0115_001;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;
import net.datastream.schemas.mp_fields.DOCUMENTENTITYID_Type;


/**
 * <p>Java class for anonymous complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType>
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}DOCUMENTENTITYID"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "documententityid"
})
@XmlRootElement(name = "MP0115_DeleteDocumentAssociation_001_Result")
public class MP0115_DeleteDocumentAssociation_001_Result {

    @XmlElement(name = "DOCUMENTENTITYID", namespace = "http://schemas.datastream.net/MP_fields", required = true)
    protected DOCUMENTENTITYID_Type documententityid;

    /**
     * Gets the value of the documententityid property.
     * 
     * @return
     *     possible object is
     *     {@link DOCUMENTENTITYID_Type }
     *     
     */
    public DOCUMENTENTITYID_Type getDOCUMENTENTITYID() {
        return documententityid;
    }

    /**
     * Sets the value of the documententityid property.
     * 
     * @param value
     *     allowed object is
     *     {@link DOCUMENTENTITYID_Type }
     *     
     */
    public void setDOCUMENTENTITYID(DOCUMENTENTITYID_Type value) {
        this.documententityid = value;
    }

}
